| Title: | A Hello Kitty Color Palette Generator |
|---|---|
| Description: | Palettes generated from Hello Kitty cartoon. |
| Authors: | Abigail Keller [aut, cre] |
| Maintainer: | Abigail Keller <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1 |
| Built: | 2026-06-18 11:41:10 UTC |
| Source: | https://github.com/abigailkeller/hellokitty |
A long dataset containing annual counts of fish returns at Bonneville Dam in the Columbia River Basin.
CRB_longCRB_long
An object of class grouped_df (inherits from tbl_df, tbl, data.frame) with 783 rows and 3 columns.
A wide dataset containing annual counts of fish returns at Bonneville Dam in the Columbia River Basin.
CRB_wideCRB_wide
An object of class grouped_df (inherits from tbl_df, tbl, data.frame) with 87 rows and 10 columns.
These are a handful of color palettes from Wes Anderson movies.
hkitty_palette(name, n, type = c("discrete", "continuous"))hkitty_palette(name, n, type = c("discrete", "continuous"))
name |
Name of desired palette. Choices are:
|
n |
Number of colors desired. If omitted, uses all colors. |
type |
Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colors. @importFrom graphics rgb rect par image text |
A vector of colors.
hkitty_palette("hellokitty1") hkitty_palette("hellokitty2") hkitty_palette("hellokitty1", 3) # If you need more colors than normally found in a palette, you # can use a continuous palette to interpolate between existing # colors pal <- hkitty_palette(name = "hellokitty2", n = 21, type = "continuous")hkitty_palette("hellokitty1") hkitty_palette("hellokitty2") hkitty_palette("hellokitty1", 3) # If you need more colors than normally found in a palette, you # can use a continuous palette to interpolate between existing # colors pal <- hkitty_palette(name = "hellokitty2", n = 21, type = "continuous")
Complete list of palettes
hkitty_paletteshkitty_palettes
No return value, called for side effects (list of color palettes).
Displays a color palette as a colored image with the palette name overlaid.
## S3 method for class 'palette' print(x, ...)## S3 method for class 'palette' print(x, ...)
x |
a palette object to print |
... |
additional arguments passed to other methods |
No return value, called for side effects (displays a color palette plot).