| Title: | A Hello Kitty Color Palette Generator |
| Description: | Palettes generated from Hello Kitty cartoon. |
| Version: | 0.1 |
| License: | MIT + file LICENSE |
| Depends: | R (≥ 3.5) |
| Encoding: | UTF-8 |
| RoxygenNote: | 8.0.0 |
| LazyData: | true |
| Suggests: | ggplot2 |
| URL: | https://github.com/abigailkeller/hellokitty |
| BugReports: | https://github.com/abigailkeller/hellokitty/issues |
| NeedsCompilation: | no |
| Packaged: | 2026-06-09 16:38:00 UTC; jovyan |
| Author: | Abigail Keller [aut, cre] |
| Maintainer: | Abigail Keller <agkeller@berkeley.edu> |
| Repository: | CRAN |
| Date/Publication: | 2026-06-17 13:30:13 UTC |
Long Format Fish Returns at Bonneville Dam
Description
A long dataset containing annual counts of fish returns at Bonneville Dam in the Columbia River Basin.
Usage
CRB_long
Format
An object of class grouped_df (inherits from tbl_df, tbl, data.frame) with 783 rows and 3 columns.
Wide Format Fish Returns at Bonneville Dam
Description
A wide dataset containing annual counts of fish returns at Bonneville Dam in the Columbia River Basin.
Usage
CRB_wide
Format
An object of class grouped_df (inherits from tbl_df, tbl, data.frame) with 87 rows and 10 columns.
A Hello kitty palette generator
Description
These are a handful of color palettes from Wes Anderson movies.
Usage
hkitty_palette(name, n, type = c("discrete", "continuous"))
Arguments
name |
Name of desired palette. Choices are:
|
n |
Number of colors desired. If omitted, uses all colors. |
type |
Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colors. @importFrom graphics rgb rect par image text |
Value
A vector of colors.
Examples
hkitty_palette("hellokitty1")
hkitty_palette("hellokitty2")
hkitty_palette("hellokitty1", 3)
# If you need more colors than normally found in a palette, you
# can use a continuous palette to interpolate between existing
# colors
pal <- hkitty_palette(name = "hellokitty2", n = 21, type = "continuous")
Complete list of palettes
Description
Complete list of palettes
Usage
hkitty_palettes
Value
No return value, called for side effects (list of color palettes).